@@ -103,7 +103,7 @@ class SyncHandler(GObject.GObject):
                 token_secret=credential['token_secret'],
                 consumer_key=credential['consumer_key'],
                 consumer_secret=credential['consumer_secret'],
-                oauth_realm='Ubuntu Software Center')
+                oauth_realm='Ubuntu One')
             self.infraclient = WebCatalogAPI(service_root=service_root,
                                              auth=authorizer)
         self._refresh_can_sync()
