@@ -29,6 +29,11 @@ class WebCatalogAPI(PistonAPI):
 #    default_service_root = 'http://localhost:8000/cat/api/1.0'
     default_service_root = 'https://apps.staging.ubuntu.com/cat/api/1.0'
     default_content_type = 'application/x-www-form-urlencoded'
+    
+    def _get(self, *args, **kwargs):
+        """Return super's _get() as str, converting it from bytes if necessary."""
+        res = super()._get(*args, **kwargs)
+        return res.decode() if type(res) == bytes else res
 
     @returns_json
     def server_status(self):
@@ -41,7 +46,7 @@ class WebCatalogAPI(PistonAPI):
         return ast.literal_eval(self._get('list-machines/', scheme=AUTHENTICATED_API_SCHEME))
 
     @validate_pattern('machine_uuid', r'[-\w+]+')
-    @validate_pattern('hostname', r'[-\w+]+')
+    @validate_pattern('hostname', r'[-\.\w+]+')
     @returns_json
     @oauth_protected
     def update_machine(self, machine_uuid, hostname):
@@ -83,7 +88,7 @@ class WebCatalogAPI(PistonAPI):
             raise APIError('Package list empty')
         # FIXME: need to do this hack to transform the http request to a json format content
         try:
-            package_list = json.loads(package_list[1:-1].replace("'", '"').replace("True", "true").replace("False", 'false'))
+            package_list = ast.literal_eval(package_list[1:-1])
         except ValueError as e:
             raise APIError('Package list invalid: %s' % e)
         return package_list
