@@ -23,7 +23,7 @@
 
 
 import dbus
-from gi.repository import GObject
+from gi.repository import GObject, GLib
 import logging
 import os
 
@@ -32,14 +32,14 @@ LOG = logging.getLogger(__name__)
 
 class NetworkStatusWatcher(GObject.GObject):
     """ simple watcher which notifys subscribers to network events..."""
-    
+
     # enums for network manager status
     # Old enum values are for NM 0.7
 
-    # The NetworkManager daemon is in an unknown state. 
+    # The NetworkManager daemon is in an unknown state.
     NM_STATE_UNKNOWN            = 0
     NM_STATE_UNKNOWN_LIST       = [NM_STATE_UNKNOWN]
-    # The NetworkManager daemon is asleep and all interfaces managed by it are inactive. 
+    # The NetworkManager daemon is asleep and all interfaces managed by it are inactive.
     NM_STATE_ASLEEP_OLD         = 1
     NM_STATE_ASLEEP             = 10
     NM_STATE_ASLEEP_LIST        = [NM_STATE_ASLEEP_OLD,
@@ -49,7 +49,7 @@ class NetworkStatusWatcher(GObject.GObject):
     NM_STATE_CONNECTING         = 40
     NM_STATE_CONNECTING_LIST    = [NM_STATE_CONNECTING_OLD,
                                    NM_STATE_CONNECTING]
-    # The NetworkManager daemon is connected. 
+    # The NetworkManager daemon is connected.
     NM_STATE_CONNECTED_OLD      = 3
     NM_STATE_CONNECTED_LOCAL    = 50
     NM_STATE_CONNECTED_SITE     = 60
@@ -66,7 +66,7 @@ class NetworkStatusWatcher(GObject.GObject):
     NM_STATE_DISCONNECTED       = 20
     NM_STATE_DISCONNECTED_LIST  = [NM_STATE_DISCONNECTED_OLD,
                                    NM_STATE_DISCONNECTED]
-    
+
     __gsignals__ = {'changed':(GObject.SIGNAL_RUN_FIRST,
                                GObject.TYPE_NONE,
                                (bool,)),
@@ -75,16 +75,18 @@ class NetworkStatusWatcher(GObject.GObject):
     def __init__(self):
         GObject.GObject.__init__(self)
         self.connected = False
-        
-        
+
+
         # check is ONECONF_NET_CONNECTED is in the environment variables
         # if so force the network status to be connected or disconnected
         if "ONECONF_NET_CONNECTED" in os.environ:
             if os.environ["ONECONF_NET_CONNECTED"].lower() == 'true':
-                GObject.idle_add(self._on_connection_state_changed, self.NM_STATE_CONNECTED_LOCAL)
+                GLib.idle_add(self._on_connection_state_changed,
+                              self.NM_STATE_CONNECTED_LOCAL)
                 LOG.warn('forced netstate into connected mode...')
             else:
-                GObject.idle_add(self._on_connection_state_changed, self.NM_STATE_DISCONNECTED)
+                GLib.idle_add(self._on_connection_state_changed,
+                              self.NM_STATE_DISCONNECTED)
                 LOG.warn('forced netstate into disconnected mode...')
             return
         try:
@@ -103,8 +105,10 @@ class NetworkStatusWatcher(GObject.GObject):
     def _on_connection_state_changed(self, state):
         LOG.debug("network status changed to %i", state)
 
-        # this is to avoid transient state when we turn wifi on and nm tell "is connected" by default until checking
-        GObject.timeout_add_seconds(1, self._ensure_new_connected_state, self._does_state_mean_connected(state))
+        # this is to avoid transient state when we turn wifi on and nm tell
+        # "is connected" by default until checking
+        GLib.timeout_add_seconds(1, self._ensure_new_connected_state,
+                                 self._does_state_mean_connected(state))
 
     def _ensure_new_connected_state(self, connected):
         '''check if the connectivity state changed since last check
@@ -120,25 +124,22 @@ class NetworkStatusWatcher(GObject.GObject):
 
     def _does_state_mean_connected(self, network_state):
         """ get bool if we the state means we are connected """
-        
+
         # unkown because in doubt, just assume we have network
         return network_state in self.NM_STATE_UNKNOWN_LIST + self.NM_STATE_CONNECTED_LIST
-        
+
 
 if __name__ == '__main__':
 
     logging.basicConfig(level=logging.DEBUG)
-    
+
     from dbus.mainloop.glib import DBusGMainLoop
     DBusGMainLoop(set_as_default=True)
     network = NetworkStatusWatcher()
     loop = GObject.MainLoop()
 
     def print_state(new_network, connected):
-        print "Connectivity state: %s" % connected
+        print("Connectivity state: %s" % connected)
     network.connect("changed", print_state)
-    
+
     loop.run()
-
-
-
